Index: post-template.php
===================================================================
--- post-template.php	(revision 21694)
+++ post-template.php	(working copy)
@@ -374,6 +374,25 @@
 }
 
 /**
+ * Retrieve the non-class items for the body element as an array.
+ *
+ * @since 3.4
+ *
+ * @param string|array $item One or more items to add to the item list.
+ */
+
+function get_body_items($item = '') {
+
+	$item = array();
+
+	$item_array = apply_filters( 'body_items', $item);
+
+	$items = empty($item_array) ? '' : ' '.join( ' ', $item_array );	
+
+return $items;
+}
+
+/**
  * Display the classes for the body element.
  *
  * @since 2.8.0
@@ -381,8 +400,12 @@
  * @param string|array $class One or more classes to add to the class list.
  */
 function body_class( $class = '' ) {
-	// Separates classes with a single space, collates classes for body element
-	echo 'class="' . join( ' ', get_body_class( $class ) ) . '"';
+
+	// get array of body element items
+	$items = get_body_items();
+
+	// Separates classes with a single space, collates classes for body element, and appends other items
+	echo 'class="' . join( ' ', get_body_class( $class ) ) . '"'. $items;
 }
 
 /**
